@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -18,27 +18,49 @@
 
 import os
 
+import gi
+
+try:
+    gi.require_version('Xfconf', '0')
+    from gi.repository import Xfconf
+    XFCONF_SUPPORT = True
+except ValueError:
+    XFCONF_SUPPORT = False
+
+from catfish_lib import helpers
+
+if XFCONF_SUPPORT:
+    Xfconf.init()
+
 DEFAULT_SETTINGS_FILE = os.path.join(os.getenv('HOME'),
                                      '.config/catfish/catfish.rc')
 DEFAULT_SETTINGS = {
-    'use-headerbar': None,
-    'show-hidden-files': False,
-    'show-sidebar': False,
-    'close-after-select': False,
-    'window-width': 650,
-    'window-height': 470,
-    'window-x': -1,
-    'window-y': -1,
-    'exclude-paths': '/dev;~/.cache;~/.gvfs;'
+    'use-headerbar': (bool, None),
+    'show-hidden-files': (bool, False),
+    'show-sidebar': (bool, True),
+    'list-toggle': (bool, True),
+    'show-thumbnails': (bool, None),
+    'search-file-contents': (bool, False),
+    'match-results-exactly': (bool, False),
+    'close-after-select': (bool, False),
+    'search-compressed-files': (bool, False),
+    'file-size-binary': (bool, True),
+    'window-width': (int, 700),
+    'window-height': (int, 540),
+    'window-x': (int, -1),
+    'window-y': (int, -1),
+    'exclude-paths': (str, '/dev;~/.cache;~/.gvfs;')
 }
 
 
 class CatfishSettings:
 
-    """CatfishSettings rc-file management."""
+    """CatfishSettings settings management."""
 
     def __init__(self, settings_file=DEFAULT_SETTINGS_FILE):
         """Initialize the CatfishSettings instance."""
+        if XFCONF_SUPPORT:
+            self.channel = Xfconf.Channel.new("catfish")
         try:
             settings_dir = os.path.dirname(settings_file)
             if not os.path.exists(settings_dir):
@@ -50,8 +72,7 @@ class CatfishSettings:
         self.read()
 
     def get_current_desktop(self):
-        current_desktop = os.environ.get("XDG_CURRENT_DESKTOP", "")
-        current_desktop = current_desktop.lower()
+        current_desktop = helpers.xdg_current_desktop()
         for desktop in ["budgie", "pantheon", "gnome"]:
             if desktop in current_desktop:
                 return desktop
@@ -91,9 +112,8 @@ class CatfishSettings:
         else:
             pass
 
-    def read(self):
-        """Read the settings rc-file into this settings instance."""
-        self.settings = DEFAULT_SETTINGS.copy()
+    def read_from_settings_file(self):
+        settings = {}
         if os.path.isfile(self.settings_file):
             try:
                 for line in open(self.settings_file):
@@ -103,11 +123,40 @@ class CatfishSettings:
                             if prop in self.settings:
                                 if value.strip().lower() in ['true', 'false']:
                                     value = value.strip().lower() == 'true'
-                                self.settings[prop] = value
+                                settings[prop] = value
                         except Exception:
                             pass
             except Exception:
                 pass
+        return settings
+
+    def delete_settings_file(self):
+        try:
+            if os.path.isfile(self.settings_file):
+                os.remove(self.settings_file)
+        except Exception:
+            pass
+
+    def read(self):
+        """Read the settings Xfconf channel into this settings instance."""
+        self.settings = {}
+        rc_settings = self.read_from_settings_file()
+        for key, value in DEFAULT_SETTINGS.items():
+            typing = value[0]
+            xfconf_prop = "/%s" % key
+            self.settings[key] = value[1]
+            if XFCONF_SUPPORT and self.channel.has_property(xfconf_prop):
+                if typing == bool:
+                    self.settings[key] = self.channel.get_bool(
+                        xfconf_prop, value[1])
+                elif typing == int:
+                    self.settings[key] = self.channel.get_int(
+                        xfconf_prop, value[1])
+                elif typing == str:
+                    self.settings[key] = self.channel.get_string(
+                        xfconf_prop, value[1])
+            elif key in rc_settings.keys():
+                self.settings[key] = rc_settings[key]
 
         if self.settings['use-headerbar'] is None:
             current_desktop = self.get_current_desktop()
@@ -118,21 +167,21 @@ class CatfishSettings:
         else:
             self.headerbar_configured = True
 
+        self.delete_settings_file()
+
     def write(self):
-        """Write the current settings to the settings rc-file."""
-        if self.settings_file:
-            try:
-                write_file = open(self.settings_file, 'w')
-                for key in list(self.settings.keys()):
-                    value = self.settings[key]
-                    if key == 'use-headerbar' and \
-                            not self.headerbar_configured:
-                        continue
-                    if isinstance(value, bool):
-                        value = str(value).lower()
-                    else:
-                        value = str(value)
-                    write_file.write('%s=%s\n' % (key, value))
-                write_file.close()
-            except PermissionError:
-                pass
+        """Write the current settings to the settings Xfconf channel."""
+        if not XFCONF_SUPPORT:
+            return
+        for key, value in DEFAULT_SETTINGS.items():
+            if key == 'use-headerbar' and \
+                    not self.headerbar_configured:
+                continue
+            typing = value[0]
+            xfconf_prop = "/%s" % key
+            if typing == bool:
+                self.channel.set_bool(xfconf_prop, self.settings[key])
+            elif typing == int:
+                self.channel.set_int(xfconf_prop, self.settings[key])
+            elif typing == str:
+                self.channel.set_string(xfconf_prop, self.settings[key])
