@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -61,6 +61,7 @@ __builder__ = {
             "fulltext": "application_menu_fulltext",
             "advanced": "application_menu_advanced",
             "update": "application_menu_update",
+            "update_separator": "application_menu_update_sep",
             "preferences": "application_menu_prefs",
         },
         # File Context Menu
@@ -82,7 +83,9 @@ __builder__ = {
             "options": "sidebar_filter_custom_date_options",
             "icons": {
                 "any": "sidebar_filter_modified_any_icon",
+                "today": "sidebar_filter_modified_day_icon",
                 "week": "sidebar_filter_modified_week_icon",
+                "month": "sidebar_filter_modified_month_icon",
                 "custom": "sidebar_filter_custom_date_icon",
                 "options": "sidebar_filter_custom_date_options_icon"
             }
@@ -197,7 +200,7 @@ class Window(Gtk.Window):
         # AppMenu
         button = Gtk.MenuButton()
         button.set_size_request(32, 32)
-        image = Gtk.Image.new_from_icon_name("emblem-system-symbolic",
+        image = Gtk.Image.new_from_icon_name("open-menu-symbolic",
                                              Gtk.IconSize.MENU)
         button.set_image(image)
         popover = Gtk.Popover.new(button)
@@ -216,6 +219,7 @@ class Window(Gtk.Window):
 
         self.search_engine = None
         self.settings = None
+        self.hidden_files = None
 
     def on_sidebar_toggle_toggled(self, widget):
         pass
@@ -229,6 +233,9 @@ class Window(Gtk.Window):
         headerbar.set_custom_title(search)
         headerbar.pack_end(button)
 
+        search.set_margin_start(42)
+        search.set_margin_end(42)
+
         self.set_titlebar(headerbar)
         headerbar.show_all()
 
@@ -237,14 +244,13 @@ class Window(Gtk.Window):
 
         toolitem = Gtk.ToolItem.new()
         toolitem.add(chooser)
-        toolitem.set_margin_right(6)
+        toolitem.set_margin_end(6)
         toolbar.insert(toolitem, 0)
 
         toolitem = Gtk.ToolItem.new()
         toolitem.add(search)
-        search.set_hexpand(True)
         toolitem.set_expand(True)
-        toolitem.set_margin_right(6)
+        toolitem.set_margin_end(6)
         toolbar.insert(toolitem, 1)
 
         toolitem = Gtk.ToolItem.new()
@@ -332,6 +338,10 @@ class Window(Gtk.Window):
             return True
         if "Control" in keys and ("q" in keys or "Q" in keys):
             self.destroy()
+            return True
+        if "Control" in keys and ("h" in keys or "H" in keys):
+            self.hidden_files.clicked()
+            return True
         if 'F9' in keys:
             self.on_sidebar_toggle_toggled(widget)
             return True
